@@ -42,25 +42,22 @@ class Video(db.Model):
     timestamp_add_video = db.Column(db.String(10), nullable=False)
     download_process_complete = db.Column(db.Boolean)
     series_id = db.Column(db.Integer, db.ForeignKey("series.series_id"))
-    actor_group_id = db.Column(db.Integer,
-                               db.ForeignKey("actor_groups.actor_group_id"))
+    actor_group_id = db.Column(db.Integer, db.ForeignKey("actor_groups.actor_group_id"))
     frames = db.relationship("Frame", backref="Video", lazy="dynamic")
-    frames_complete = db.relationship("Frame_Complete",
-                                      backref="Video",
-                                      lazy="dynamic")
+    frames_complete = db.relationship("Frame_Complete", backref="Video", lazy="dynamic")
     objects = db.relationship("Object", backref="Video", lazy="dynamic")
-    objects_complete = db.relationship("Object_Complete",
-                                       backref="Video",
-                                       lazy="dynamic")
+    objects_complete = db.relationship(
+        "Object_Complete", backref="Video", lazy="dynamic"
+    )
     triggers = db.relationship("Trigger", backref="Video", lazy="dynamic")
     faces = db.relationship("Face", backref="Video", lazy="dynamic")
-    facenet_haar_predictions = db.relationship("Facenet_Haar_Prediction",
-                                               backref=backref("Video",
-                                                               uselist=False))
+    facenet_haar_predictions = db.relationship(
+        "Facenet_Haar_Prediction", backref=backref("Video", uselist=False)
+    )
 
-    __table_args__ = (db.UniqueConstraint("video_id",
-                                          "episode_id",
-                                          name="episode_video"), )
+    __table_args__ = (
+        db.UniqueConstraint("video_id", "episode_id", name="episode_video"),
+    )
 
 
 class Frame(db.Model):
@@ -71,13 +68,13 @@ class Frame(db.Model):
     video_id = db.Column(db.Integer, db.ForeignKey("videos.video_id"))
     frame_number = db.Column(db.Integer, nullable=False)
     objects = db.relationship("Object", backref="Frame", lazy="dynamic")
-    face = db.relationship("Face",
-                           backref=backref("Frame", uselist=False),
-                           lazy="dynamic")
+    face = db.relationship(
+        "Face", backref=backref("Frame", uselist=False), lazy="dynamic"
+    )
 
-    __table_args__ = (db.UniqueConstraint("video_id",
-                                          "frame_number",
-                                          name="video_frame"), )
+    __table_args__ = (
+        db.UniqueConstraint("video_id", "frame_number", name="video_frame"),
+    )
 
 
 class Frame_Complete(db.Model):
@@ -87,17 +84,18 @@ class Frame_Complete(db.Model):
     frame_id = db.Column(db.Integer, primary_key=True)
     video_id = db.Column(db.Integer, db.ForeignKey("videos.video_id"))
     frame_number = db.Column(db.Integer, nullable=False)
-    objects_complete = db.relationship("Object_Complete",
-                                       backref="Frame_Complete",
-                                       lazy="dynamic")
-    faces_complete = db.relationship("Face_Complete",
-                                     backref=backref("Frame_Complete",
-                                                     uselist=False),
-                                     lazy="dynamic")
+    objects_complete = db.relationship(
+        "Object_Complete", backref="Frame_Complete", lazy="dynamic"
+    )
+    faces_complete = db.relationship(
+        "Face_Complete",
+        backref=backref("Frame_Complete", uselist=False),
+        lazy="dynamic",
+    )
 
-    __table_args__ = (db.UniqueConstraint("video_id",
-                                          "frame_number",
-                                          name="video_frame"), )
+    __table_args__ = (
+        db.UniqueConstraint("video_id", "frame_number", name="video_frame"),
+    )
 
 
 class Object(db.Model):
@@ -114,23 +112,23 @@ class Object(db.Model):
     object_y = db.Column(db.Integer, nullable=False)
     object_w = db.Column(db.Integer, nullable=False)
     object_h = db.Column(db.Integer, nullable=False)
-    character_label = db.relationship("Character_Label",
-                                      backref=backref("Object", uselist=False))
-    object_pca_features = db.relationship("Object_PCA_Features",
-                                          backref=backref("Object",
-                                                          uselist=False))
-    object_umap_features = db.relationship("Object_UMAP_Features",
-                                           backref=backref("Object",
-                                                           uselist=False))
+    character_label = db.relationship(
+        "Character_Label", backref=backref("Object", uselist=False)
+    )
+    object_pca_features = db.relationship(
+        "Object_PCA_Features", backref=backref("Object", uselist=False)
+    )
+    object_umap_features = db.relationship(
+        "Object_UMAP_Features", backref=backref("Object", uselist=False)
+    )
     face = db.relationship("Face", backref=backref("Object", uselist=False))
-    facenet_haar_predictions = db.relationship("Facenet_Haar_Prediction",
-                                               backref=backref("Object",
-                                                               uselist=False))
+    facenet_haar_predictions = db.relationship(
+        "Facenet_Haar_Prediction", backref=backref("Object", uselist=False)
+    )
 
-    __table_args__ = (db.UniqueConstraint("video_id",
-                                          "frame_id",
-                                          "object_number",
-                                          name="object"), )
+    __table_args__ = (
+        db.UniqueConstraint("video_id", "frame_id", "object_number", name="object"),
+    )
 
 
 class Object_Complete(db.Model):
@@ -147,14 +145,14 @@ class Object_Complete(db.Model):
     object_y = db.Column(db.Integer, nullable=False)
     object_w = db.Column(db.Integer, nullable=False)
     object_h = db.Column(db.Integer, nullable=False)
-    faces_complete = db.relationship("Face_Complete",
-                                     backref=backref("Object_Complete",
-                                                     uselist=False),
-                                     lazy="dynamic")
-    facenet_haar_predictions = db.relationship("Facenet_Haar_Prediction",
-                                               backref=backref(
-                                                   "Object_Complete",
-                                                   uselist=False))
+    faces_complete = db.relationship(
+        "Face_Complete",
+        backref=backref("Object_Complete", uselist=False),
+        lazy="dynamic",
+    )
+    facenet_haar_predictions = db.relationship(
+        "Facenet_Haar_Prediction", backref=backref("Object_Complete", uselist=False)
+    )
     # character_label = db.relationship(
     #     "Character_Label", backref=backref("Object", uselist=False))
     # object_pca_features = db.relationship(
@@ -166,10 +164,9 @@ class Object_Complete(db.Model):
     # facenet_haar_predictions = db.relationship(
     #     "Facenet_Haar_Prediction", backref=backref("Object", uselist=False))
 
-    __table_args__ = (db.UniqueConstraint("video_id",
-                                          "frame_id",
-                                          "object_number",
-                                          name="object"), )
+    __table_args__ = (
+        db.UniqueConstraint("video_id", "frame_id", "object_number", name="object"),
+    )
 
 
 class Face(db.Model):
@@ -183,10 +180,9 @@ class Face(db.Model):
     episode_id = db.Column(db.Integer, db.ForeignKey("episodes.episode_id"))
     object_number = db.Column(db.Integer, nullable=False)
 
-    __table_args__ = (db.UniqueConstraint("video_id",
-                                          "frame_id",
-                                          "object_number",
-                                          name="object"), )
+    __table_args__ = (
+        db.UniqueConstraint("video_id", "frame_id", "object_number", name="object"),
+    )
 
 
 class Face_Complete(db.Model):
@@ -194,17 +190,15 @@ class Face_Complete(db.Model):
     __tablename__ = "faces_complete"
 
     face_id = db.Column(db.Integer, primary_key=True)
-    object_id = db.Column(db.Integer,
-                          db.ForeignKey("objects_complete.object_id"))
+    object_id = db.Column(db.Integer, db.ForeignKey("objects_complete.object_id"))
     video_id = db.Column(db.Integer, db.ForeignKey("videos.video_id"))
     frame_id = db.Column(db.Integer, db.ForeignKey("frames_complete.frame_id"))
     episode_id = db.Column(db.Integer, db.ForeignKey("episodes.episode_id"))
     object_number = db.Column(db.Integer, nullable=False)
 
-    __table_args__ = (db.UniqueConstraint("video_id",
-                                          "frame_id",
-                                          "object_number",
-                                          name="object"), )
+    __table_args__ = (
+        db.UniqueConstraint("video_id", "frame_id", "object_number", name="object"),
+    )
 
 
 class Dlib_Face_Unaligned(db.Model):
@@ -222,10 +216,11 @@ class Dlib_Face_Unaligned(db.Model):
     object_h = db.Column(db.Integer, nullable=False)
     # character_label = db.relationship("Character_Label", backref=backref("Dlib_Face_Unaligned", uselist=False))
 
-    __table_args__ = (db.UniqueConstraint("video_id",
-                                          "frame_id",
-                                          "object_number",
-                                          name="dlib_face_unaligned"), )
+    __table_args__ = (
+        db.UniqueConstraint(
+            "video_id", "frame_id", "object_number", name="dlib_face_unaligned"
+        ),
+    )
 
 
 class Dlib_Face_Aligned(db.Model):
@@ -243,10 +238,11 @@ class Dlib_Face_Aligned(db.Model):
     object_h = db.Column(db.Integer, nullable=False)
     # character_label = db.relationship("Character_Label", backref=backref("Dlib_Face_Aligned", uselist=False))
 
-    __table_args__ = (db.UniqueConstraint("video_id",
-                                          "frame_id",
-                                          "object_number",
-                                          name="dlib_faces_aligned"), )
+    __table_args__ = (
+        db.UniqueConstraint(
+            "video_id", "frame_id", "object_number", name="dlib_faces_aligned"
+        ),
+    )
 
 
 class Character_Label(db.Model):
@@ -255,13 +251,12 @@ class Character_Label(db.Model):
 
     character_label_id = db.Column(db.Integer, primary_key=True)
     object_id = db.Column(db.Integer, db.ForeignKey("objects.object_id"))
-    character_id = db.Column(db.Integer,
-                             db.ForeignKey("characters.character_id"))
+    character_id = db.Column(db.Integer, db.ForeignKey("characters.character_id"))
     timestamp_labelled = db.Column(db.String(10), nullable=False)
 
-    __table_args__ = (db.UniqueConstraint("object_id",
-                                          "character_id",
-                                          name="object_label"), )
+    __table_args__ = (
+        db.UniqueConstraint("object_id", "character_id", name="object_label"),
+    )
 
 
 class Series(db.Model):
@@ -289,9 +284,9 @@ class Season(db.Model):
     series_id = db.Column(db.Integer, db.ForeignKey("series.series_id"))
     timestamp_add_season = db.Column(db.String(10), nullable=False)
 
-    __table_args__ = (db.UniqueConstraint("series_id",
-                                          "season_number",
-                                          name="series_season"), )
+    __table_args__ = (
+        db.UniqueConstraint("series_id", "season_number", name="series_season"),
+    )
 
 
 class Episode(db.Model):
@@ -306,13 +301,13 @@ class Episode(db.Model):
     series_id = db.Column(db.Integer, db.ForeignKey("series.series_id"))
     season_id = db.Column(db.Integer, db.ForeignKey("seasons.season_id"))
     video = db.relationship("Video", backref="Episode", uselist=False)
-    face = db.relationship("Face",
-                           backref=backref("Episode", uselist=False),
-                           lazy="dynamic")
+    face = db.relationship(
+        "Face", backref=backref("Episode", uselist=False), lazy="dynamic"
+    )
 
-    __table_args__ = (db.UniqueConstraint("episode_number",
-                                          "season_id",
-                                          name="season_episode"), )
+    __table_args__ = (
+        db.UniqueConstraint("episode_number", "season_id", name="season_episode"),
+    )
 
 
 class Actor(db.Model):
@@ -323,9 +318,9 @@ class Actor(db.Model):
     actor_name = db.Column(db.String(128), nullable=False)
     timestamp_add_actor = db.Column(db.String(10), nullable=False)
     characters = db.relationship("Character", backref="Actor", lazy="dynamic")
-    actor_group_lookups = db.relationship("Actor_Group_Lookup",
-                                          backref="Actor",
-                                          lazy="dynamic")
+    actor_group_lookups = db.relationship(
+        "Actor_Group_Lookup", backref="Actor", lazy="dynamic"
+    )
 
 
 class Actor_Group(db.Model):
@@ -335,9 +330,9 @@ class Actor_Group(db.Model):
     actor_group_id = db.Column(db.Integer, primary_key=True)
     actor_group_name = db.Column(db.String(64), nullable=False)
     timestamp_add_actor_group = db.Column(db.String(10), nullable=False)
-    actor_group_lookups = db.relationship("Actor_Group_Lookup",
-                                          backref="Actor_Group",
-                                          lazy="dynamic")
+    actor_group_lookups = db.relationship(
+        "Actor_Group_Lookup", backref="Actor_Group", lazy="dynamic"
+    )
     videos = db.relationship("Video", backref="Actor_Group", lazy="dynamic")
 
 
@@ -346,12 +341,10 @@ class Actor_Group_Lookup(db.Model):
     __tablename__ = "actor_group_lookup"
 
     actor_group_lookup_id = db.Column(db.Integer, primary_key=True)
-    actor_group_id = db.Column(db.Integer,
-                               db.ForeignKey("actor_groups.actor_group_id"),
-                               nullable=False)
-    actor_id = db.Column(db.Integer,
-                         db.ForeignKey("actors.actor_id"),
-                         nullable=False)
+    actor_group_id = db.Column(
+        db.Integer, db.ForeignKey("actor_groups.actor_group_id"), nullable=False
+    )
+    actor_id = db.Column(db.Integer, db.ForeignKey("actors.actor_id"), nullable=False)
     timestamp_add_actor_group_lookup = db.Column(db.String(10), nullable=False)
 
 
@@ -360,21 +353,20 @@ class Character(db.Model):
     __tablename__ = "characters"
 
     character_id = db.Column(db.Integer, primary_key=True)
-    series_id = db.Column(db.Integer,
-                          db.ForeignKey("series.series_id"),
-                          nullable=False)
-    actor_id = db.Column(db.Integer,
-                         db.ForeignKey("actors.actor_id"),
-                         nullable=False)
+    series_id = db.Column(db.Integer, db.ForeignKey("series.series_id"), nullable=False)
+    actor_id = db.Column(db.Integer, db.ForeignKey("actors.actor_id"), nullable=False)
     character_name = db.Column(db.String(128), nullable=False)
     timestamp_add_character = db.Column(db.String(10), nullable=False)
-    facenet_haar_predictions = db.relationship("Facenet_Haar_Prediction",
-                                               backref=backref("Character",
-                                                               uselist=False))
+    character_labels = db.relationship(
+        "Character_Label", backref="Character", lazy="dynamic"
+    )
+    facenet_haar_predictions = db.relationship(
+        "Facenet_Haar_Prediction", backref=backref("Character", uselist=False)
+    )
 
-    __table_args__ = (db.UniqueConstraint("series_id",
-                                          "character_name",
-                                          name="series_character"), )
+    __table_args__ = (
+        db.UniqueConstraint("series_id", "character_name", name="series_character"),
+    )
 
 
 class Process(db.Model):
@@ -393,18 +385,16 @@ class Trigger(db.Model):
     __tablename__ = "triggers"
 
     trigger_id = db.Column(db.Integer, primary_key=True)
-    video_id = db.Column(db.Integer,
-                         db.ForeignKey("videos.video_id"),
-                         nullable=False)
-    process_id = db.Column(db.Integer,
-                           db.ForeignKey("processes.process_id"),
-                           nullable=False)
+    video_id = db.Column(db.Integer, db.ForeignKey("videos.video_id"), nullable=False)
+    process_id = db.Column(
+        db.Integer, db.ForeignKey("processes.process_id"), nullable=False
+    )
     timestamp_add_trigger = db.Column(db.String(10), nullable=False)
     status_complete = db.Column(db.Boolean, nullable=False)
 
-    __table_args__ = (db.UniqueConstraint("video_id",
-                                          "process_id",
-                                          name="video_process"), )
+    __table_args__ = (
+        db.UniqueConstraint("video_id", "process_id", name="video_process"),
+    )
 
 
 class Session_Info(db.Model):
@@ -422,9 +412,7 @@ class Haar_Cascade(db.Model):
 
     __tablename__ = "haar_cascades"
 
-    haar_cascade_id = db.Column(db.Integer,
-                                primary_key=True,
-                                autoincrement=True)
+    haar_cascade_id = db.Column(db.Integer, primary_key=True, autoincrement=True)
     haar_cascade_name = db.Column(db.String(32), primary_key=True)
     file = db.Column(db.String(48), primary_key=True)
 
@@ -433,9 +421,7 @@ class Object_PCA_Features(db.Model):
 
     __tablename__ = "object_pca_features"
 
-    object_pca_features_id = db.Column(db.Integer,
-                                       primary_key=True,
-                                       autoincrement=True)
+    object_pca_features_id = db.Column(db.Integer, primary_key=True, autoincrement=True)
     object_id = db.Column(db.Integer, db.ForeignKey("objects.object_id"))
     feature_1 = db.Column(db.Numeric(7, 6), nullable=False)
     feature_2 = db.Column(db.Numeric(7, 6), nullable=False)
@@ -476,9 +462,9 @@ class Object_UMAP_Features(db.Model):
 
     __tablename__ = "object_umap_features"
 
-    object_umap_features_id = db.Column(db.Integer,
-                                        primary_key=True,
-                                        autoincrement=True)
+    object_umap_features_id = db.Column(
+        db.Integer, primary_key=True, autoincrement=True
+    )
     object_id = db.Column(db.Integer, db.ForeignKey("objects.object_id"))
     feature_1 = db.Column(db.Numeric(7, 6), nullable=False)
     feature_2 = db.Column(db.Numeric(7, 6), nullable=False)
@@ -519,77 +505,75 @@ class Facenet_Haar_Model(db.Model):
 
     __tablename__ = "facenet_haar_models"
 
-    facenet_haar_model_id = db.Column(db.Integer,
-                                      primary_key=True,
-                                      autoincrement=True)
+    facenet_haar_model_id = db.Column(db.Integer, primary_key=True, autoincrement=True)
     model_name = db.Column(db.String(24), unique=True, nullable=False)
     series_id = db.Column(db.Integer, db.ForeignKey("series.series_id"))
     timestamp_added = db.Column(db.String(10), nullable=False)
-    model_input_data = db.relationship("Facenet_Haar_Model_Input_Data",
-                                       backref="Facenet_Haar_Model",
-                                       lazy="dynamic")
-    model_predictions = db.relationship("Facenet_Haar_Prediction",
-                                        backref="Facenet_Haar_Model",
-                                        lazy="dynamic")
+    model_input_data = db.relationship(
+        "Facenet_Haar_Model_Input_Data", backref="Facenet_Haar_Model", lazy="dynamic"
+    )
+    model_predictions = db.relationship(
+        "Facenet_Haar_Prediction", backref="Facenet_Haar_Model", lazy="dynamic"
+    )
 
 
 class Facenet_Haar_Model_Input_Data(db.Model):
 
     __tablename__ = "facenet_haar_model_input_data"
 
-    facenet_haar_model_input_data_id = db.Column(db.Integer,
-                                                 primary_key=True,
-                                                 autoincrement=True)
-    object_id = db.Column(db.Integer,
-                          db.ForeignKey("objects.object_id"),
-                          nullable=False)
-    character_id = db.Column(db.Integer,
-                             db.ForeignKey("characters.character_id"),
-                             nullable=False)
-    model_name = db.Column(db.String(24),
-                           db.ForeignKey("facenet_haar_models.model_name"),
-                           nullable=False)
+    facenet_haar_model_input_data_id = db.Column(
+        db.Integer, primary_key=True, autoincrement=True
+    )
+    object_id = db.Column(
+        db.Integer, db.ForeignKey("objects.object_id"), nullable=False
+    )
+    character_id = db.Column(
+        db.Integer, db.ForeignKey("characters.character_id"), nullable=False
+    )
+    model_name = db.Column(
+        db.String(24), db.ForeignKey("facenet_haar_models.model_name"), nullable=False
+    )
     timestamp_added = db.Column(db.String(10), nullable=False)
 
-    __table_args__ = (db.UniqueConstraint(
-        "model_name",
-        "object_id",
-        name="facenet_haar_model_input_model_object"), )
+    __table_args__ = (
+        db.UniqueConstraint(
+            "model_name", "object_id", name="facenet_haar_model_input_model_object"
+        ),
+    )
 
 
 class Facenet_Haar_Prediction(db.Model):
 
     __tablename__ = "facenet_haar_predictions"
 
-    facenet_haar_prediction_id = db.Column(db.Integer,
-                                           primary_key=True,
-                                           autoincrement=True)
-    object_id = db.Column(db.Integer,
-                          db.ForeignKey("objects.object_id"),
-                          nullable=False)
-    object_complete_id = db.Column(db.Integer,
-                                   db.ForeignKey("objects_complete.object_id"),
-                                   nullable=True)
-    video_id = db.Column(db.Integer,
-                         db.ForeignKey("videos.video_id"),
-                         nullable=False)
-    character_id = db.Column(db.Integer,
-                             db.ForeignKey("characters.character_id"),
-                             nullable=False)
-    facenet_haar_model_name = db.Column(
-        db.String(24),
-        db.ForeignKey("facenet_haar_models.model_name"),
-        nullable=False)
+    facenet_haar_prediction_id = db.Column(
+        db.Integer, primary_key=True, autoincrement=True
+    )
+    object_id = db.Column(
+        db.Integer, db.ForeignKey("objects.object_id"), nullable=False
+    )
+    object_complete_id = db.Column(
+        db.Integer, db.ForeignKey("objects_complete.object_id"), nullable=True
+    )
+    video_id = db.Column(db.Integer, db.ForeignKey("videos.video_id"), nullable=False)
+    character_id = db.Column(
+        db.Integer, db.ForeignKey("characters.character_id"), nullable=False
+    )
+    facenet_haar_model_name = db.Column(db.String(24), nullable=False)
     timestamp_added = db.Column(db.String(10), nullable=False)
 
     __table_args__ = (
-        db.UniqueConstraint("object_id",
-                            "video_id",
-                            "facenet_haar_model_name",
-                            name="facenet_haar_prediction_and_model"),
-        db.UniqueConstraint("facenet_haar_model_name",
-                            "object_id",
-                            name="facenet_haar_prediction_model_object"),
+        db.UniqueConstraint(
+            "object_id",
+            "video_id",
+            "facenet_haar_model_name",
+            name="facenet_haar_prediction_and_model",
+        ),
+        db.UniqueConstraint(
+            "facenet_haar_model_name",
+            "object_id",
+            name="facenet_haar_prediction_model_object",
+        ),
     )
 
 
@@ -597,26 +581,26 @@ class Facenet_Haar_Prediction_Complete(db.Model):
 
     __tablename__ = "facenet_haar_predictions_complete"
 
-    facenet_haar_prediction_complete_id = db.Column(db.Integer,
-                                                    primary_key=True,
-                                                    autoincrement=True)
-    object_id = db.Column(db.Integer,
-                          db.ForeignKey("objects_complete.object_id"),
-                          nullable=False)
-    video_id = db.Column(db.Integer,
-                         db.ForeignKey("videos.video_id"),
-                         nullable=False)
-    character_id = db.Column(db.Integer,
-                             db.ForeignKey("characters.character_id"),
-                             nullable=False)
+    facenet_haar_prediction_complete_id = db.Column(
+        db.Integer, primary_key=True, autoincrement=True
+    )
+    object_id = db.Column(
+        db.Integer, db.ForeignKey("objects_complete.object_id"), nullable=False
+    )
+    video_id = db.Column(db.Integer, db.ForeignKey("videos.video_id"), nullable=False)
+    character_id = db.Column(
+        db.Integer, db.ForeignKey("characters.character_id"), nullable=False
+    )
     facenet_haar_model_name = db.Column(db.String(24), nullable=False)
     timestamp_added = db.Column(db.String(10), nullable=False)
 
     __table_args__ = (
-        db.UniqueConstraint("object_id",
-                            "video_id",
-                            name="facenet_haar_prediction_complete"),
-        db.UniqueConstraint("facenet_haar_model_name",
-                            "object_id",
-                            name="facenet_haar_prediction_complete_model"),
+        db.UniqueConstraint(
+            "object_id", "video_id", name="facenet_haar_prediction_complete"
+        ),
+        db.UniqueConstraint(
+            "facenet_haar_model_name",
+            "object_id",
+            name="facenet_haar_prediction_complete_model",
+        ),
     )
